@@ -28,7 +28,8 @@ class GSCNodeFunctionReceiverSocket:
 
         @self.sio.event
         def oncnodefunction(id, msg):
-            msg1 = ubjson.loadb(msg)
+            msg1 =  msgpack.unpackb(msg, raw=False)
+
             self._pool.apply_async(self.oncnodefunction, args=[self.gsdbs, id, msg1],
                                    callback=on_success,
                                    error_callback=on_errorPost)
@@ -117,7 +118,8 @@ class GSCNodeFunctionCaller:
     def emitFunction(self, sio, target, msg):
         msg["cnodefunction"] = target
 
-        encoded = ubjson.dumpb(msg)
+        encoded = msgpack.packb(msg, use_bin_type=True)
+
         sio.emit("oncnodefunction", {"target": target, "data": encoded})
 
     def sendcnodefunction(self, target, msg):
